@@ -1,4 +1,5 @@
 import os
+import re
 from netCDF4 import Dataset
 import cftime
 import numpy as np
@@ -6,6 +7,9 @@ import ds_format as ds
 import datetime as dt
 import aquarius_time as aq
 
+JD_UNITS = 'days since -4713-11-24 12:00 UTC'
+JD_CALENDAR = 'proleptic_greogorian'
+
 READ_EXT = ['nc', 'nc4', 'nc3', 'netcdf', 'hdf', 'h5']
 WRITE_EXT = ['nc', 'nc4', 'netcdf']
 
@@ -54,6 +58,10 @@ def process_datetime_var(d, name):
 	shape = d[name].shape
 	units = d['.'][name].get(u'units')
 	calendar = d['.'][name].get(u'calendar', u'standard')
+	if re.match(r'^days since -4712-01-01[T ]12:00(:00)?( UTC)?$', units) and \
+	   calendar in (None, 'standard'):
+		units = 'days since -4713-11-24 12:00 UTC'
+		calendar = 'proleptic_gregorian'
 	try:
 		x = cftime.num2date(x, units,
 			calendar=calendar,
@@ -72,9 +80,8 @@ def process_datetime_var(d, name):
 			x[i] = dt.datetime(x[i].year, 1, 1) + \
 			(x[i] - type(x[i])(x[i].year, 1, 1))
 	d[name] = aq.from_datetime(list(x)).reshape(shape)
-	d['.'][name]['units'] = 'days since -4712-01-01 12:00 UTC'
-	if 'calendar' in d['.'][name]:
-		del d['.'][name]['calendar']
+	d['.'][name]['units'] = 'days since -4713-11-24 12:00 UTC'
+	d['.'][name]['calendar'] = 'proleptic_gregorian'
 
 def read(filename, variables=None, sel=None, full=False, jd=False):
 	if type(filename) is bytes and str != bytes:
@@ -95,33 +102,25 @@ def read(filename, variables=None, sel=None, full=False, jd=False):
 	return d
 
 def write(filename, d):
+	ds.validate(d)
 	if type(filename) is bytes and hasattr(os, 'fsdecode'):
 		filename = os.fsdecode(filename)
 	with Dataset(filename, 'w') as f:
 		dims = ds.get_dims(d)
 		for k, v in dims.items():
 			f.createDimension(k, v)
-		for name, data in d.items():
-			if name.startswith('.'):
-				continue
-			var = d['.'][name]
-			if type(data) is not np.ndarray:
-				data = np.array([data])
+		for name in ds.get_vars(d):
+			data = ds.get_var(d, name)
 			if data.dtype == 'O' and \
 				len(data.flatten()) > 0 and \
 				type(data.flatten()[0]) is str:
 				dtype = str
 			else:
 				dtype = data.dtype
-			v = f.createVariable(name, dtype, var['.dims'])
-			v.setncatts({
-				k: v
-				for k, v in var.items()
-				if not k.startswith('.')
-			})
+			v = f.createVariable(name, dtype, ds.get_dims(d, name))
+			v.setncatts(ds.get_attrs(d, name))
 			v[::] = data
-		if '.' in d['.']:
-			f.setncatts(d['.']['.'])
+		f.setncatts(ds.get_attrs(d))
 
 from_netcdf = read
 to_netcdf = write
